
package QRgen;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.EncodeHintType;
import com.google.zxing.MultiFormatWriter;
import com.google.zxing.WriterException;
import com.google.zxing.client.j2se.MatrixToImageConfig;
import java.io.IOException;
import java.util.HashMap;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.qrcode.decoder.ErrorCorrectionLevel;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.image.BufferedImage;

/**
 *
 * @author xfeda002
 */
public class QRgen {
    public final String data;
    public final int width;
    public final int height;
    public final String charset;
    public final HashMap<EncodeHintType, Object> hashMap;
    //public final ErrorCorrectionLevel errorCorrection;
    //public final int qrVersion;
    //public final int margin;
    public final Color mainColor;
    public final int backgroundColor;
    
    public QRgen ( String data, int width, int height, String charset, 
            ErrorCorrectionLevel errorCorrection, 
            int qrVersion, 
            int margin, 
            Color mainColor, int backgroundColor )
    {
        this.data = data;
        this.width = width;
        this.height = height;
        this.charset = charset;
        this.hashMap = new HashMap();
        this.hashMap.put(EncodeHintType.ERROR_CORRECTION, errorCorrection);
        this.hashMap.put(EncodeHintType.QR_VERSION, qrVersion);
        this.hashMap.put(EncodeHintType.MARGIN, margin);
        //this.errorCorrection = errorCorrection;
        //this.qrVersion = qrVersion;
        //this.margin = margin;
        this.backgroundColor = backgroundColor;
        this.mainColor = mainColor;
    }
    
    public int height()
    {
        return height;
    }
    
    public int width()
    {
        return width;
    }
    
    public BitMatrix generateQRcode() 
            throws WriterException, IOException  
    {  
        BitMatrix matrix = new MultiFormatWriter().encode(new String(data.getBytes(charset), charset), BarcodeFormat.QR_CODE, width, height, hashMap); 
        return matrix;
    } 
    
//    public BufferedImage convertToBufferedImageSquare (BitMatrix matrix)
//    {
//        MatrixToImageConfig conf = new MatrixToImageConfig(mainColor, backgroundColor);
//        return toBufferedImage(matrix, conf);  
//    }
    
    public BufferedImage convertToBufferedImage (BitMatrix matrix)
    {
        BufferedImage image = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
        Graphics2D graphics = image.createGraphics();

        graphics.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
        graphics.setBackground(Color.white);
        graphics.clearRect(0, 0, width, height);
        graphics.setColor(mainColor);
                      
        for (int i = 0; i < width; i++)
        {
            for (int j = 0; j < height; j++)
            {
                if (matrix.get(i, j) == true)
                {
                    graphics.fillOval(i, j, 3, 3);
                }
            }
        }

        graphics.dispose();
        return image;
    }
}
